@@ -454,6 +454,9 @@ class HDF5Reader:
         info += f'MARKERS: {list(self.markers.keys())}\n'
         for k in self.header:
             info += f"{k.upper()}: {self.header[k]}\n"
+        ts = self.header['shape'][1] / self.header['sample_rate']
+        info += f"DURATION: {ts:.1f} seconds ({ts/60:.1f} minutes)\n"
+
         info += sep
         return info
 
@@ -656,7 +659,7 @@ class HDF5Reader:
         # return timestamp
 
     # ----------------------------------------------------------------------
-    @cached_property
+    @property
     def classes_indexes(self) -> Dict[str, int]:
         """The standard for classes and indexes."""
         return {key: (i + 1) for i, key in enumerate(self.markers.keys())}
@@ -682,7 +685,7 @@ class HDF5Reader:
         self.f.close()
 
     # ----------------------------------------------------------------------
-    def get_epochs(self, tmax: int, tmin: Optional[int] = 0, markers: Union[None, List[str]] = None, preprocess=None, eeg=None, **kwargs) -> mne.EpochsArray:
+    def get_epochs(self, tmax: int, tmin: Optional[int] = 0, ref=None, markers: Union[None, List[str]] = None, preprocess=None, eeg=None, **kwargs) -> mne.EpochsArray:
         """Create an `EpochsArray` object with the `MNE` library.
 
         This method auto crop the data in regard to markers also will drop
@@ -745,6 +748,13 @@ class HDF5Reader:
         if markers is None:
             markers = self.classes_indexes.keys()
 
+        if ref:
+            if isinstance(ref, str):
+                n = list(channels_names).index(ref)
+                eeg = eeg - eeg[n]
+            else:
+                eeg = eeg - ref
+
         classes = []
         data = []
         no_fit = 0
@@ -775,6 +785,13 @@ class HDF5Reader:
         else:
             data = np.array(data)
 
+        # if ref:
+            # if isinstance(ref, str):
+                # n = list(self.header['channels'].values()).index(ref)
+                # data = data - data[n]
+            # else:
+                # data = data - ref
+
         # raw = mne.io.RawArray(data, info, first_samp=0,
                               # copy='auto', verbose=None)
         # return mne.Epochs(raw, events=events, tmin=tmin, event_id=event_id, **kwargs)
@@ -875,7 +892,7 @@ class HDF5Reader:
         f.close()
 
     # ----------------------------------------------------------------------
-    def get_data(self, tmax: int, tmin: Optional[int] = 0, markers: Union[None, List[str]] = None, eeg=None, preprocess=None, **kwargs) -> Tuple[np.ndarray]:
+    def get_data(self, tmax: int, tmin: Optional[int] = 0, ref=None, markers: Union[None, List[str]] = None, eeg=None, preprocess=None, **kwargs) -> Tuple[np.ndarray]:
         """Create an `EpochsArray` object with the `MNE` library.
 
         This method auto crop the data in regard to markers also will drop
@@ -902,7 +919,7 @@ class HDF5Reader:
         """
 
         epochs = self.get_epochs(
-            tmax, tmin, markers, eeg=eeg, preprocess=preprocess)
+            tmax, tmin, ref, markers, eeg=eeg, preprocess=preprocess, **kwargs)
         return epochs._data, epochs.events[:, 2]
 
     # # ----------------------------------------------------------------------
@@ -966,10 +983,10 @@ class HDF5Reader:
         return timestamp[raw == 1]
 
     # ----------------------------------------------------------------------
-    def fix_markers(self, target_markers, rises, range_=2000):
+    def fix_markers(self, target_markers, rises, range_=2000, overwrite=False):
         """"""
         global_ = {}
-        for mk in target_markers:
+        for mk in list(target_markers)[:]:
 
             offsets = []
             for m in self.markers[mk]:
@@ -977,8 +994,12 @@ class HDF5Reader:
                 if abs(Q - m) < range_:
                     offsets.append([m, Q])
 
-            offsets = np.array(offsets)
-            self.markers[f'{mk}_fixed'] = offsets[:, 1]
-            global_[mk] = np.median(np.diff(offsets))
+            if len(offsets):
+                offsets = np.array(offsets)
+                if overwrite:
+                    self.markers[mk] = offsets[:, 1]
+                else:
+                    self.markers[f'{mk}_fixed'] = offsets[:, 1]
+                global_[mk] = np.median(np.diff(offsets))
 
         return global_
